==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/outputs/WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property efsFileLocation Specifies the details for the EFS file being copied.
 * @property s3FileLocation Specifies the details for the S3 file being copied.
 */
public data class WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation(
    public val efsFileLocation:
    WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationEfsFileLocation? = null,
    public val s3FileLocation:
    WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationS3FileLocation? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.transfer.outputs.WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation):
            WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation =
            WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation(
                efsFileLocation = javaType.efsFileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationEfsFileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3FileLocation = javaType.s3FileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationS3FileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/outputs/WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property efsFileLocation Specifies the details for the EFS file being copied.
 * @property s3FileLocation Specifies the details for the S3 file being copied.
 */
public data class WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation(
    public val efsFileLocation: WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationEfsFileLocation? = null,
    public val s3FileLocation: WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationS3FileLocation? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.transfer.outputs.WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation): WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation =
            WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocation(
                efsFileLocation = javaType.efsFileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationEfsFileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3FileLocation = javaType.s3FileLocation().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.transfer.kotlin.outputs.WorkflowOnExceptionStepCopyStepDetailsDestinationFileLocationS3FileLocation.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
